@@ -9,7 +9,7 @@ use Padre::Util ('_T');
 use base 'Padre::Plugin';
 
 # exports and version
-our $VERSION   = '0.41';
+our $VERSION   = '0.42';
 our @EXPORT_OK = qw(plugin_config);
 
 # constants for html exporting
@@ -33,7 +33,7 @@ sub _sharedir {
 
 # Returns the plugin name to Padre
 sub plugin_name {
-	return _T("Perl 6");
+	return Wx::gettext("Perl 6");
 }
 
 # directory where to find the translations
@@ -84,7 +84,7 @@ sub menu_plugins {
 	# Perl6 S29 documentation
 	Wx::Event::EVT_MENU(
 		$main,
-		$self->{menu}->Append( -1, _T("Show Perl 6 Help\tF2"), ),
+		$self->{menu}->Append( -1, Wx::gettext("Show Perl 6 Help\tF2"), ),
 		sub { $self->show_perl6_doc; },
 	);
 
@@ -93,13 +93,13 @@ sub menu_plugins {
 	# Manual Perl6 syntax highlighting
 	Wx::Event::EVT_MENU(
 		$main,
-		$self->{menu}->Append( -1, _T("Refresh Coloring\tF7"), ),
+		$self->{menu}->Append( -1, Wx::gettext("Refresh Coloring\tF7"), ),
 		sub { $self->highlight; },
 	);
 
 	# Toggle Auto Perl6 syntax highlighting
 	$self->{p6_highlight} =
-		$self->{menu}->AppendCheckItem( -1, _T("Enable Auto Coloring"),);
+		$self->{menu}->AppendCheckItem( -1, Wx::gettext("Enable Auto Coloring"),);
 	Wx::Event::EVT_MENU(
 		$main,
 		$self->{p6_highlight},
@@ -112,17 +112,17 @@ sub menu_plugins {
 	# Export into HTML
 	Wx::Event::EVT_MENU(
 		$main,
-		$self->{menu}->Append( -1, _T("Export Full HTML"), ),
+		$self->{menu}->Append( -1, Wx::gettext("Export Full HTML"), ),
 		sub { $self->export_html($FULL_HTML); },
 	);
 	Wx::Event::EVT_MENU(
 		$main,
-		$self->{menu}->Append( -1, _T("Export Simple HTML"), ),
+		$self->{menu}->Append( -1, Wx::gettext("Export Simple HTML"), ),
 		sub { $self->export_html($SIMPLE_HTML); },
 	);
 	Wx::Event::EVT_MENU(
 		$main,
-		$self->{menu}->Append( -1, _T("Export Snippet HTML"), ),
+		$self->{menu}->Append( -1, Wx::gettext("Export Snippet HTML"), ),
 		sub { $self->export_html($SNIPPET_HTML); },
 	);
 
@@ -131,14 +131,14 @@ sub menu_plugins {
 	# Generate Perl 6 Executable
 	Wx::Event::EVT_MENU(
 		$main,
-		$self->{menu}->Append( -1, _T("Generate Perl 6 Executable"), ),
+		$self->{menu}->Append( -1, Wx::gettext("Generate Perl 6 Executable"), ),
 		sub { $self->generate_p6_exe; },
 	);
 
 	# Generate Perl 6 PIR
 	Wx::Event::EVT_MENU(
 		$main,
-		$self->{menu}->Append( -1, _T("Generate Perl 6 PIR"), ),
+		$self->{menu}->Append( -1, Wx::gettext("Generate Perl 6 PIR"), ),
 		sub { $self->generate_p6_pir; },
 	);
 	
@@ -147,7 +147,7 @@ sub menu_plugins {
 	# Cleanup STD.pm lex cache
 	Wx::Event::EVT_MENU(
 		$main,
-		$self->{menu}->Append( -1, _T("Cleanup STD.pm Lex Cache"), ),
+		$self->{menu}->Append( -1, Wx::gettext("Cleanup STD.pm Lex Cache"), ),
 		sub { $self->cleanup_std_lex_cache; },
 	);
 
@@ -156,7 +156,7 @@ sub menu_plugins {
 	# Preferences
 	Wx::Event::EVT_MENU(
 		$main,
-		$self->{menu}->Append( -1, _T("Preferences"), ),
+		$self->{menu}->Append( -1, Wx::gettext("Preferences"), ),
 		sub { $self->show_preferences; },
 	);
 
@@ -165,7 +165,7 @@ sub menu_plugins {
 	# the famous about menu item...
 	Wx::Event::EVT_MENU(
 		$main,
-		$self->{menu}->Append( -1, _T("About"), ),
+		$self->{menu}->Append( -1, Wx::gettext("About"), ),
 		sub { $self->show_about },
 	);
 
@@ -174,7 +174,7 @@ sub menu_plugins {
 }
 
 sub registered_documents {
-	'application/x-perl6' => 'Padre::Document::Perl6',
+	'application/x-perl6' => 'Padre::Plugin::Perl6::Perl6Document',
 }
 
 sub show_preferences {
@@ -193,8 +193,8 @@ sub show_about {
 	my $about = Wx::AboutDialogInfo->new;
 	$about->SetName("Padre::Plugin::Perl6");
 	$about->SetDescription(
-		_T("Perl 6 syntax highlighting is based on\n") .
-		_T("Syntax::Highlight::Perl6 version ") . $Syntax::Highlight::Perl6::VERSION . "\n"
+		Wx::gettext("Perl 6 syntax highlighting is based on\n") .
+		Wx::gettext("Syntax::Highlight::Perl6 version ") . $Syntax::Highlight::Perl6::VERSION . "\n"
 	);
 	$about->SetVersion($VERSION);
 	Wx::AboutBox( $about );
@@ -212,7 +212,7 @@ sub cleanup_std_lex_cache {
 	my $LEX_STD_DIR = 'lex/STD';
 	if(! -d $LEX_STD_DIR) {
 		Wx::MessageBox(
-			_T("Cannot find STD.pm lex cache"),
+			Wx::gettext("Cannot find STD.pm lex cache"),
 			'Error',
 			Wx::wxOK,
 			$main,
